API documentation
=================

The following documentation is based on the source code of version |release| of
the `colouredlogs` package.

The most useful entry points into the documentation are
:func:`~colouredlogs.install()`, :class:`~colouredlogs.ColouredFormatter` and
:func:`~colouredlogs.syslog.enable_system_logging()`.

The :mod:`colouredlogs` module
-----------------------------

.. automodule:: colouredlogs
   :members:

The :mod:`colouredlogs.converter` module
---------------------------------------

.. automodule:: colouredlogs.converter
   :members:

The :mod:`colouredlogs.syslog` module
------------------------------------

.. automodule:: colouredlogs.syslog
   :members:
